@@ -1,6 +1,6 @@
 //
 // ====================================================================
-// Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+// Copyright (c) 2003-2008 Barry A Scott.  All rights reserved.
 //
 // This software is licensed as described in the file LICENSE.txt,
 // which you should have received as part of this distribution.
@@ -10,7 +10,7 @@
 //
 //  pysvn_callbacks.cpp
 //
-#ifdef _MSC_VER
+#if defined( _MSC_VER )
 // disable warning C4786: symbol greater than 255 character,
 // nessesary to ignore as <map> causes lots of warning
 #pragma warning(disable: 4786)
@@ -24,7 +24,7 @@ pysvn_context::pysvn_context( const std::string &config_dir )
 : SvnContext( config_dir )
 , m_pyfn_GetLogin()
 , m_pyfn_Notify()
-#ifdef PYSVN_HAS_CONTEXT_PROGRESS
+#if defined( PYSVN_HAS_CONTEXT_PROGRESS )
 , m_pyfn_Progress()
 #endif
 , m_pyfn_GetLogMessage()
@@ -141,7 +141,7 @@ bool pysvn_context::contextGetLogin
     return false;
 }
 
-#ifdef PYSVN_HAS_CONTEXT_PROGRESS
+#if defined( PYSVN_HAS_CONTEXT_PROGRESS )
 void pysvn_context::contextProgress
     (
     apr_off_t progress,
@@ -182,7 +182,7 @@ void pysvn_context::contextProgress
 // the progress of an ongoing action
 //
 
-#ifdef PYSVN_HAS_CONTEXT_NOTIFY2
+#if defined( PYSVN_HAS_CONTEXT_NOTIFY2 )
 void pysvn_context::contextNotify2
     (
     const svn_wc_notify_t *notify,
@@ -442,7 +442,7 @@ bool pysvn_context::contextSslServerTrustPrompt
 // this method is called to retrieve client side
 // information
 //
-bool pysvn_context::contextSslClientCertPrompt( std::string & certFile )
+bool pysvn_context::contextSslClientCertPrompt( std::string &_cert_file, const std::string &_realm, bool &_may_save )
 {
     PythonDisallowThreads callback_permission( m_permission );
 
@@ -453,10 +453,31 @@ bool pysvn_context::contextSslClientCertPrompt( std::string & certFile )
         return false;
     }
 
-    Py::Tuple args( 0 );
+    Py::Callable callback( m_pyfn_SslClientCertPrompt );
+
+    Py::Tuple args( 2 );
+    args[0] = Py::String( _realm );
+    args[1] = Py::Int( _may_save );
+
+    Py::Tuple results;
+    Py::Int retcode;
+    Py::String cert_file;
+    Py::Int may_save_out;
+
     try
     {
-        return get_string( m_pyfn_SslClientCertPrompt, args, certFile );
+        results = callback.apply( args );
+        retcode = results[0];
+        cert_file = results[1];
+        may_save_out = results[2];
+
+        if( long( retcode ) != 0 )
+        {
+            _cert_file = cert_file.as_std_string();
+            _may_save = long( may_save_out ) != 0;
+
+            return true;
+        }
     }
     catch( Py::Exception &e )
     {
@@ -464,6 +485,8 @@ bool pysvn_context::contextSslClientCertPrompt( std::string & certFile )
         e.clear();
 
         m_error_message = "unhandled exception in callback_ssl_client_cert_prompt";
+
+        return false;
     }
 
     return false;
