@@ -1,6 +1,6 @@
 //
 // ====================================================================
-// Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+// Copyright (c) 2003-2008 Barry A Scott.  All rights reserved.
 //
 // This software is licensed as described in the file LICENSE.txt,
 // which you should have received as part of this distribution.
@@ -8,7 +8,7 @@
 // ====================================================================
 //
 
-#ifdef _MSC_VER
+#if defined( _MSC_VER )
 // disable warning C4786: symbol greater than 255 character,
 // nessesary to ignore as <map> causes lots of warning
 #pragma warning(disable: 4786)
@@ -20,6 +20,10 @@
 
 static const char name_utf8[] = "utf-8";
 static const std::string str_URL( "URL" );
+static const std::string str_changelist( "changelist" );
+static const std::string str_depth( "depth" );
+static const std::string str_working_size( "working_size" );
+static const std::string str_size( "size" );
 static const std::string str_checksum( "checksum" );
 static const std::string str_comment( "comment" );
 static const std::string str_commit_author( "commit_author" );
@@ -274,7 +278,7 @@ Py::Object toObject
     entry[ str_text_time ] = toObject( svn_entry.text_time );
     entry[ str_url ] = utf8_string_or_none( svn_entry.url );
     entry[ str_uuid ] = utf8_string_or_none( svn_entry.uuid );
-#ifdef PYSVN_HAS_CLIENT_STATUS2
+#if defined( PYSVN_HAS_CLIENT_STATUS2 )
     entry[ str_lock_token ] = utf8_string_or_none( svn_entry.lock_token );
     entry[ str_lock_owner ] = utf8_string_or_none( svn_entry.lock_owner );
     entry[ str_lock_comment ] = utf8_string_or_none( svn_entry.lock_comment );
@@ -285,7 +289,7 @@ Py::Object toObject
 }
 
 
-#ifdef PYSVN_HAS_CLIENT_INFO
+#if defined( PYSVN_HAS_CLIENT_INFO )
 Py::Object toObject
     (
     const svn_info_t &info,
@@ -294,6 +298,7 @@ Py::Object toObject
     const DictWrapper &wrapper_wc_info
     )
 {
+
     Py::Dict py_info;
 
     // Where the item lives in the repository.
@@ -323,7 +328,7 @@ Py::Object toObject
     // The author of the last_changed_rev.
     py_info[str_last_changed_author] = utf8_string_or_none( info.last_changed_author );
 
-#ifdef PYSVN_HAS_CLIENT_LOCK
+#if defined( PYSVN_HAS_CLIENT_LOCK )
     // An exclusive lock, if present.  Could be either local or remote.
     if( info.lock == NULL )
     {
@@ -355,14 +360,38 @@ Py::Object toObject
         py_wc_info[str_conflict_new] = utf8_string_or_none( info.conflict_new );
         py_wc_info[str_conflict_work] = utf8_string_or_none( info.conflict_wrk );
         py_wc_info[str_prejfile] = utf8_string_or_none( info.prejfile );
-
+#ifdef PYSVN_HAS_SVN_INFO_T__CHANGELIST
+        py_wc_info[str_changelist] = utf8_string_or_none( info.changelist );
+        py_wc_info[str_depth] = toEnumValue( info.depth );
+#endif
+#ifdef PYSVN_HAS_SVN_INFO_T__SIZES
+#ifdef HAVE_LONG_LONG
+        if( info.working_size == SVN_INFO_SIZE_UNKNOWN )
+            py_wc_info[str_working_size] = Py::None();
+        else
+            py_wc_info[str_working_size] = Py::LongLong( static_cast<PY_LONG_LONG>( info.working_size ) );
+        if( info.size == SVN_INFO_SIZE_UNKNOWN )
+            py_wc_info[str_size] = Py::None();
+        else
+            py_wc_info[str_size] = Py::LongLong( static_cast<PY_LONG_LONG>( info.size ) );
+#else
+        if( info.working_size == SVN_INFO_SIZE_UNKNOWN )
+            py_wc_info[str_working_size] = Py::None();
+        else
+            py_wc_info[str_working_size] = Py::Int( static_cast<int>( info.working_size ) );
+        if( info.size == SVN_INFO_SIZE_UNKNOWN )
+            py_wc_info[str_size] = Py::None();
+        else
+            py_wc_info[str_size] = Py::Int( static_cast<int>( info.size ) );
+#endif
+#endif
         py_info[str_wc_info] = wrapper_wc_info.wrapDict( py_wc_info );
     }
 
     return wrapper_info.wrapDict( py_info );
 }
 #endif
-#ifdef PYSVN_HAS_CLIENT_LOCK
+#if defined( PYSVN_HAS_CLIENT_LOCK )
 Py::Object toObject
     (
     const svn_lock_t &lock,
@@ -549,3 +578,35 @@ Py::List toListOfStrings( Py::Object obj )
     return list;
 }
 
+apr_hash_t *hashOfStringsFromDistOfStrings( Py::Object arg, SvnPool &pool )
+{
+    Py::Dict dict( arg );
+
+    apr_hash_t *hash = apr_hash_make( pool );
+
+    std::string type_error_message;
+    try
+    {
+        Py::List all_keys( dict.keys() );
+
+        for( Py::List::size_type i=0; i<all_keys.length(); i++ )
+        {
+            type_error_message = "expecting string key in dict";
+            Py::String key( asUtf8String( all_keys[i] ) );
+
+            type_error_message = "expecting string value in dict";
+            Py::String value( asUtf8String( dict[ key ] ) );
+
+            char *hash_key = apr_pstrdup( pool, key.as_std_string().c_str() );
+            svn_string_t *hash_value = svn_string_create( value.as_std_string().c_str(), pool );
+
+            apr_hash_set( hash, hash_key, APR_HASH_KEY_STRING, hash_value );
+        }
+    }
+    catch( Py::TypeError & )
+    {
+        throw Py::TypeError( type_error_message );
+    }
+
+    return hash;
+}
