@@ -1,6 +1,6 @@
 //
 // ====================================================================
-// (c) 2003-2006 Barry A Scott.  All rights reserved.
+// (c) 2003-2008 Barry A Scott.  All rights reserved.
 //
 // This software is licensed as described in the file LICENSE.txt,
 // which you should have received as part of this distribution.
@@ -11,7 +11,7 @@
 //    pysvn_transaction.cpp
 //
 
-#ifdef _MSC_VER
+#if defined( _MSC_VER )
 // disable warning C4786: symbol greater than 255 character,
 // nessesary to ignore as <map> causes lots of warning
 #pragma warning(disable: 4786)
