@@ -1,6 +1,6 @@
 #
 # ====================================================================
-# (c) 2005-2007 Barry A Scott.  All rights reserved.
+# (c) 2005-2008 Barry A Scott.  All rights reserved.
 #
 # This software is licensed as described in the file LICENSE.txt,
 # which you should have received as part of this distribution.
@@ -54,6 +54,7 @@ def setup_help( argv ):
         --verbose
         --enable-debug
         --pycxx-dir=<dir>
+        --pycxx-src-dir=<dir>
         --apr-inc-dir=<dir>
         --svn-root-dir=<dir>
         --svn-inc-dir=<dir>
@@ -134,6 +135,9 @@ class MakeFileCreater:
         # add pycxx include
         pycxx_dir = self.find_pycxx( argv )
         include_dir_list.append( pycxx_dir )
+        # add pycxx source
+        pycxx_src_dir = self.find_pycxx_src( argv, pycxx_dir )
+        include_dir_list.append( pycxx_src_dir )
         # add SVN include
         svn_include = self.find_svn_inc( argv )
         include_dir_list.append( svn_include )
@@ -194,11 +198,17 @@ class MakeFileCreater:
             'lib_apr':          self.lib_apr,    # set as a side effect of find_apr_lib
 
             # pycxx src dir
-            'pycxx_dir':        pycxx_dir
+            'pycxx_dir':        pycxx_dir,
+
+            # pycxx src dir
+            'pycxx_src_dir':        pycxx_src_dir
             }
 
         print 'Info: Creating Makefile for Source'
 
+        major, minor, patch = self.getSvnVersion( svn_include )
+        template_values[ 'svn_version_maj_min' ] = '%d.%d' % (major, minor)
+
         makefile = file( 'Makefile', 'w' )
         if self.is_mac_os_x:
             # need to figure out the framework dir to use otherwise the latest
@@ -290,7 +300,7 @@ class MakeFileCreater:
 #       -- makefile_tests_template --
 #
 PYTHON=%(python_exe)s
-
+SVN_VERSION_MAJ_MIN=%(svn_version_maj_min)s
 #include pysvn_test_common.mak
 '''
 
@@ -305,6 +315,7 @@ CCCFLAGS=-Wall -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s %(debug_cfla
 CC=gcc -c
 CCFLAGS=-Wall -fPIC %(includes)s %(debug_cflags)s
 PYCXX=%(pycxx_dir)s
+PYCXXSRC=%(pycxx_src_dir)s
 LDSHARED=g++ -shared %(debug_cflags)s
 LDLIBS=-L%(svn_lib_dir)s -Wl,--rpath -Wl,%(svn_lib_dir)s \
 -lsvn_client-1 \
@@ -326,12 +337,13 @@ CCCFLAGS=-Wall -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s %(debug_cfla
 CC=gcc -c
 CCFLAGS=-Wall -fPIC %(includes)s %(debug_cflags)s
 PYCXX=%(pycxx_dir)s
+PYCXXSRC=%(pycxx_src_dir)s
 LDSHARED=g++ -shared %(debug_cflags)s
 LDLIBS=-L%(svn_lib_dir)s -Wl,--rpath -Wl,%(svn_lib_dir)s \
 -lsvn_client-1 \
 -lsvn_diff-1 \
 -lsvn_repos-1 \
- -lgssapi_krb5 -lkrb5 -lk5crypto -lkrb5support -lcom_err -lresolv -lexpat -lneon
+ -lcom_err -lresolv -lexpat -lneon
 
 #include pysvn_common.mak
 '''
@@ -347,6 +359,7 @@ CCCFLAGS=-Wall -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s %(debug_cfla
 CC=gcc -c
 CCFLAGS=-Wall -fPIC %(includes)s %(debug_cflags)s
 PYCXX=%(pycxx_dir)s
+PYCXXSRC=%(pycxx_src_dir)s
 LDSHARED=g++ -shared %(debug_cflags)s
 LDLIBS=-L%(svn_lib_dir)s -Wl,--rpath -Wl,/usr/lib:/usr/local/lib:%(svn_lib_dir)s \
 -lsvn_client-1 \
@@ -368,6 +381,7 @@ CCCFLAGS=-Wall -fexceptions -frtti %(includes)s %(py_cflags)s %(debug_cflags)s
 CC=gcc -c
 CCFLAGS=-Wall %(includes)s %(debug_cflags)s
 PYCXX=%(pycxx_dir)s
+PYCXXSRC=%(pycxx_src_dir)s
 LDSHARED=g++ -shared %(debug_cflags)s
 LDLIBS=-L%(svn_lib_dir)s \
 -L/usr/lib/python2.5/config -lpython2.5.dll \
@@ -407,6 +421,7 @@ CCCFLAGS=-Wall -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s %(debug_cfla
 CC=gcc -c
 CCFLAGS=-Wall -fPIC %(includes)s %(debug_cflags)s
 PYCXX=%(pycxx_dir)s
+PYCXXSRC=%(pycxx_src_dir)s
 LDSHARED=g++ -shared %(debug_cflags)s
 LDLIBS=-L%(svn_lib_dir)s \
 -lsvn_client-1   \
@@ -446,6 +461,7 @@ CCCFLAGS=-Wall -Wno-long-double -fPIC -fexceptions -frtti %(includes)s %(py_cfla
 CC=gcc -c
 CCFLAGS=-Wall -Wno-long-double -fPIC %(includes)s %(debug_cflags)s
 PYCXX=%(pycxx_dir)s
+PYCXXSRC=%(pycxx_src_dir)s
 LDSHARED=g++ -bundle %(debug_cflags)s -u _PyMac_Error %(frameworks)s
 LDLIBS=-L%(svn_lib_dir)s \
 -L%(apr_lib_dir)s \
@@ -470,6 +486,7 @@ CCCFLAGS=-Wall -Wno-long-double -fPIC -fexceptions -frtti %(includes)s %(py_cfla
 CC=gcc -c
 CCFLAGS=-Wall -Wno-long-double -fPIC %(includes)s %(debug_cflags)s -isysroot /Developer/SDKs/MacOSX10.4u.sdk -arch ppc -arch i386
 PYCXX=%(pycxx_dir)s
+PYCXXSRC=%(pycxx_src_dir)s
 LDSHARED=g++ -bundle -twolevel_namespace %(debug_cflags)s -u _PyMac_Error %(frameworks)s -Wl,-syslibroot,/Developer/SDKs/MacOSX10.4u.sdk -arch ppc -arch i386
 LDLIBS=-L%(svn_lib_dir)s \
 -L%(apr_lib_dir)s \
@@ -495,6 +512,7 @@ CCCFLAGS=-Wall -Wno-long-double -fPIC -fexceptions -frtti %(includes)s %(py_cfla
 CC=gcc -c
 CCFLAGS=-Wall -Wno-long-double -fPIC %(includes)s %(debug_cflags)s
 PYCXX=%(pycxx_dir)s
+PYCXXSRC=%(pycxx_src_dir)s
 LDSHARED=g++ -bundle %(debug_cflags)s -u _PyMac_Error %(frameworks)s
 LDLIBS= \
 %(svn_lib_dir)s/libsvn_client-1.a \
@@ -534,6 +552,7 @@ CCCFLAGS=-Wall -Wno-long-double -fPIC -fexceptions -frtti %(includes)s %(py_cfla
 CC=gcc -c
 CCFLAGS=-Wall -Wno-long-double -fPIC %(includes)s %(debug_cflags)s
 PYCXX=%(pycxx_dir)s
+PYCXXSRC=%(pycxx_src_dir)s
 LDSHARED=g++ -bundle %(debug_cflags)s -u _PyMac_Error %(frameworks)s
 LDLIBS= \
 %(svn_lib_dir)s/libsvn_client-1.a \
@@ -569,9 +588,23 @@ LDLIBS= \
                     'PyCXX include',
                     '--pycxx-dir=',
                     None,
-                    [   '../Import/pycxx-5.4.0'],
+                    [
+                        '../Import/pycxx-5.4.1',
+                        distutils.sysconfig.get_python_inc() # typical Linux
+                    ],
                     'CXX/Version.hxx' )
 
+    def find_pycxx_src( self, argv, pycxx_dir ):
+        return self.find_dir( argv,
+                    'PyCXX Source',
+                    '--pycxx-src-dir=',
+                    None,
+                    [
+                        '%s/Src' % pycxx_dir,
+                        '/usr/share/python%s/CXX' % distutils.sysconfig.get_python_version() # typical Linux
+                    ],
+                    'cxxsupport.cxx' )
+
     def find_svn_inc( self, argv ):
         return self.find_dir( argv,
                     'SVN include',
@@ -598,7 +631,7 @@ LDLIBS= \
                         '/usr/lib',                             # typical Linux
                         '/usr/local/lib64',                     # typical 64bit Linux
                         '/usr/local/lib',                       # typical *BSD
-                        '/usr/pkg/lib',                         # netbsb
+                        '/usr/pkg/lib',                         # netbsd
                     ],
                     self.get_lib_name_for_platform( 'libsvn_client-1' ) )
         # if we are using the Fink SVN then remember this
@@ -620,7 +653,7 @@ LDLIBS= \
             except SetupError:
                 pass
 
-        for apr_ver in ['apr-1', 'apr-0']:
+        for apr_ver in ['apr-1.0', 'apr-1', 'apr-0']:
             try:
                 return self.find_dir( argv,
                     'APR include',
@@ -713,5 +746,24 @@ LDLIBS= \
 
         raise SetupError, 'cannot find %s %s - use %s' % (name, check_file, kw)
 
+    def getSvnVersion( self, svn_include ):
+        all_svn_version_lines = file( os.path.join( svn_include, 'svn_version.h' ) ).readlines()
+        major = None
+        minor = None
+        patch = None
+        for line in all_svn_version_lines:
+            words = line.strip().split()
+            if len(words) > 2 and words[0] == '#define':
+                if words[1] == 'SVN_VER_MAJOR':
+                    major = int(words[2])
+                elif words[1] == 'SVN_VER_MINOR':
+                    minor = int(words[2])
+                elif words[1] == 'SVN_VER_PATCH':
+                    patch = int(words[2])
+ 
+        print 'Info: Building against SVN %d.%d.%d' % (major, minor, patch)
+        return (major, minor, patch)
+
+
 if __name__ == '__main__':
     sys.exit( main( sys.argv ) )
